/**
 * @vendor Summit
 * @module Magento_Checkout
 * @copyright Copyright (c) 2016 Summit Media Limited (http://www.summit.co.uk/)
 * @license http://opensource.org/licenses/afl-3.0.php Academic Free License (AFL 3.0)
 */
define([
    'Magento_Checkout/js/view/form/element/email',
    'jquery',
    'uiComponent',
    'ko',
    'Magento_Checkout/js/model/step-navigator',
    'Magento_Customer/js/model/customer',
    'Magento_Customer/js/action/check-email-availability',
    'Magento_Customer/js/action/login',
    'Magento_Checkout/js/model/quote',
    'Magento_Checkout/js/checkout-data',
    'Magento_Checkout/js/model/full-screen-loader',
    'mage/validation'
], function (email, $, Component, ko, stepNavigator, customer, checkEmailAvailability, loginAction, quote, checkoutData) {
    'use strict';

    var validatedEmail;

    validatedEmail = checkoutData.getValidatedEmailValue();

    if (validatedEmail && !customer.isLoggedIn()) {
        quote.guestEmail = validatedEmail;
    }

    return email.extend({
        defaults: {
            template: 'Dexanet_AwesomeCheckout/form/element/email',
            radioPasswordChanged: ko.observable('no_password'),
            email: checkoutData.getInputFieldEmailValue(),
            emailFocused: false,
            isLoading: false,
            isPasswordVisible: false,
            listens: {
                radioPasswordChanged: 'passwordChanges',
                email: 'emailHasChanged',
                emailFocused: 'validateEmail'
            },
            ignoreTmpls: {
                email: true
            }
        },

        /**
         * Initializes observable properties of instance
         *
         * @returns {Object} Chainable.
         */
        initObservable: function () {
            this._super()
                .observe(['radioPasswordChanged', 'email', 'emailFocused', 'isLoading', 'isPasswordVisible']);
            return this;
        },

        passwordChanges: function () {
            var hasPassword = $('[name="isPasswordNeeded"]:checked').val() === 'has_password';
            this.isPasswordVisible(hasPassword);

            if (hasPassword) {
                $('#checkout-step-customer-account > .actions-toolbar').hide();
            } else {
                $('#checkout-step-customer-account > .actions-toolbar').show();
            }
        },

        /**
         * Callback on changing email property
         */
        emailHasChanged: function () {
            var self = this;

            clearTimeout(this.emailCheckTimeout);

            if (self.validateEmail()) {
                quote.guestEmail = self.email();
                checkoutData.setValidatedEmailValue(self.email());
            }
            this.emailCheckTimeout = setTimeout(function () {
                if (self.validateEmail()) {
                    self.checkEmailAvailability();
                }
            }, self.checkDelay);

            checkoutData.setInputFieldEmailValue(self.email());
        },

        /**
         * Check email existing.
         */
        checkEmailAvailability: function () {
            this.validateRequest();
            this.isEmailCheckComplete = $.Deferred();
            this.isLoading(true);
            this.checkRequest = checkEmailAvailability(this.isEmailCheckComplete, this.email());

            $.when(this.isEmailCheckComplete).done(function () {
                // Do nothing
            }.bind(this)).always(function () {
                // this.isPasswordVisible(true);
                this.isLoading(false);
            }.bind(this));
        }
    });
});
