/**
 * @category Summit
 * @package Summit\Checkout
 * @copyright Copyright (c) 2016 Summit Media Limited (http://www.summit.co.uk/)
 * @license http://opensource.org/licenses/afl-3.0.php Academic Free License (AFL 3.0)
 */
define([
    'Magento_Checkout/js/view/shipping',
    'ko',
    'Magento_Customer/js/model/customer',
    'Magento_Checkout/js/model/quote',
    'Magento_Checkout/js/action/set-shipping-information',
    'Magento_Checkout/js/model/step-navigator',
    'jquery',
    'mage/translate'
], function (shipping, ko, customer, quote, setShippingInformationAction, stepNavigator, $, $t) {
    'use strict';

    var isEswCheckout = window.checkoutConfig.isEswCheckoutEnabled,
        eswNoticeBlock = window.checkoutConfig.eswCheckoutNotice,
        checkoutUrl = window.checkoutConfig.checkoutUrl;

    return shipping.extend({
        defaults: {
            template: 'Dexanet_AwesomeCheckout/shipping'
        },

        isCustomerLoggedIn: window.isCustomerLoggedIn,
        visible: ko.observable(!quote.isVirtual() && window.isCustomerLoggedIn),
        formPopupOpenedOnce: false,
        eswNotice: eswNoticeBlock,
        initialize: function () {
            var self = this;
            this._super();

            // SW - Disable "Add address" button when shipping methods are loading
            this.isFormPopUpVisible.subscribe(function (value) {
                if (value) {
                    self.formPopupOpenedOnce = true;
                }
            });
            this.isLoading.subscribe(function (value) {
                if (!quote.isVirtual() && self.isCustomerLoggedIn && self.formPopupOpenedOnce) {
                    var $buttons = $(self.getPopUp().buttons),
                        $saveButton = $buttons.filter('.action-save-address'),
                        disabled = value ? true : null;
                    $saveButton.attr('disabled', disabled);
                }
                if (!quote.isVirtual()) {
                    var $continueButton = $('#shipping-method-buttons-container .action.primary'),
                        disabled = value ? true : null;
                    $continueButton.attr('disabled', disabled);
                }
            });

            return this;
        },
        setShippingInformation: function () {
            var shippingAddress = quote.shippingAddress(),
                $form = $('#co-shipping-method-form'),
                $submit = $form.find('button[type=submit]'),
                $buttons = $('button');

            $('.empty-shipping-address').remove();

            // Fixes M2 bug where form can be submitted when no addresses are chosen
            if (window.isCustomerLoggedIn) {
                if ((shippingAddress.getKey() == 'new-customer-address' && this.isNewAddressAdded()) ||
                    (shippingAddress.getKey().length > 0 && shippingAddress.getKey() != 'new-customer-address') ||
                    this.isFormInline) {

                    this.saveShippingInformationAndProceed();
                } else {
                    var noShippingError = $t('Please choose a shipping address.');
                    $submit.after('<div class="mage-error empty-shipping-address">' + noShippingError + '</div>');
                    $buttons.on('click.co-shipping-method-form', function () {
                        $('.empty-shipping-address').remove();
                        $buttons.off('click.co-shipping-method-form');
                    });
                }
            } else {
                this.saveShippingInformationAndProceed();
            }
        },
        saveShippingInformationAndProceed: function () {
            if (this.validateShippingInformation()) {
                setShippingInformationAction().done(
                    function () {
                        stepNavigator.next();
                    }
                );
            }
        },
        navigate: function () {
            //load data from server for shipping step
            this.visible(true);
        }
    });
});